@@ -4,9 +4,8 @@
 # See COPYING or http://www.opensource.org/licenses/mit-license.php.
 
 NAME = 'crumbs'
-VERSION = '1.1.1'
-DESCRIPTION = \
-        'Generalized all-in-one parameters module.'
+VERSION = '1.1.2'
+DESCRIPTION = 'Generalized all-in-one parameters module.'
 AUTHOR = 'Alex Brandt'
 AUTHOR_EMAIL = 'alunduil@alunduil.com'
 URL = 'https://github.com/alunduil/crumbs'
